<?php

declare(strict_types=1);

namespace Drupal\uberflip_api;

/**
 * Provides Uberflip API integration and authentication with open id.
 */
interface UberflipClientInterface {

  /**
   * Gets an access token used to authenticate requests to the API.
   *
   * @return string
   *   Returns the API token.
   */
  public function getApiToken(): string;

  /**
   * The details of an item.
   *
   * @param int $item_id
   *   The unique identifier of the item.
   *
   * @return array|null
   *   Assoc array with the details of an item or NULL if no item is in
   *   response.
   */
  public function getItem(int $item_id): ?array;

  /**
   * A paginated list of all Items in a Stream.
   *
   * @param int $stream_id
   *   The ID code that identifies the Stream.
   *
   * @return array|null
   *   Assoc array with stream items or NULL if no items are in response.
   */
  public function getStreamListItems(int $stream_id): ?array;

}
